package org.apache.maven;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

/**
 * MavenSession constants.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: MavenConstants.java 423634 2006-07-19 22:13:40Z aheritier $
 */
public class MavenConstants
{
    /**
     * This is an internal version for MavenSession self updating
     * procedures. A MavenSession installation can query a MavenSession
     * installation distributor to see if it is up-to-date
     * and self-update if required.
     */
    public static final int MAVEN_VERSION = 3;

    /**
     * This is the version of the POM that this version of
     * MavenSession operates with. If a descrepancy is found between
     * the version of the POM being used and the version of
     * the POM that this version of MavenSession can deal with then
     * the POM will be transformed into compliance.
     */
    public static final int POM_VERSION = 3;

    /** Online tag. */
    public static final String ONLINE = "maven.mode.online";

    /** Jar Override tag. */
    public static final String JAR_OVERRIDE = "maven.jar.override";

    /** Jar Override property tag. */
    public static final String JAR_OVERRIDE_PROPERTY = "maven.jar.";

    /** Local Repository tag. */
    public static final String REPO_LOCAL = "maven.repo.local";

    /** Local Repository tag. */
    public static final String REPO_REMOTE = "maven.repo.remote";

    /** Local Repository enabled tag. */
    public static final String REPO_REMOTE_ENABLED = "maven.repo.remote.enabled";

    /** Proxy host tag. */
    public static final String PROXY_HOST = "maven.proxy.host";

    /** Proxy port tag. */
    public static final String PROXY_PORT = "maven.proxy.port";

    /** Proxy user name tag. */
    public static final String PROXY_USERNAME = "maven.proxy.username";

    /** Proxy password tag. */
    public static final String PROXY_PASSWORD = "maven.proxy.password";

    /** Proxy loginHost tag. */
    public static final String PROXY_NTLM_HOST = "maven.proxy.ntlm.host";

    /** Proxy loginDomain tag. */
    public static final String PROXY_NTLM_DOMAIN = "maven.proxy.ntlm.domain";

    /** Non-proxied hosts. */
    public static final String PROXY_NONPROXYHOSTS = "maven.proxy.nonProxyHosts";

    /** Download meter type variable. */
    public static final String DOWNLOAD_METER = "maven.download.meter";

    /** Snapshot JAR signifier tag. */
    public static final String SNAPSHOT_SIGNIFIER = "SNAPSHOT";

    /** Driver properties */
    public static final String DRIVER_PROPERTIES = "/driver.properties";

    /**  Project build file name. (maven.xml) */
    public static final String BUILD_FILE_NAME = "maven.xml";

    /** Defaults goal name property. */
    public static final String DEFAULT_GOAL = "maven.default.goal";

    /** Defaults properties */
    public static final String DEFAULTS_PROPERTIES = "/defaults.properties";

    // Context tags.

    /** MavenSession home context tag **/
    public static final String MAVEN_HOME = "maven.home";

    /** MavenSession home local context tag **/
    public static final String MAVEN_HOME_LOCAL = "maven.home.local";

    /** MavenSession plugins context tag **/
    public static final String MAVEN_PLUGINS_DIR = "maven.plugin.dir";

    /** MavenSession unpacked plugins context tag **/
    public static final String MAVEN_UNPACKED_PLUGINS_DIR = "maven.plugin.unpacked.dir";

    /** MavenSession local plugins context tag **/
    public static final String MAVEN_USER_PLUGINS_DIR = "maven.plugin.user.dir";

    /** MavenSession build file url context tag **/
    public static final String MAVEN_BUILD_FILE_URL = "maven.project.buildFile.url";

    /** MavenSession ant project context tag **/
    public static final String MAVEN_ANT_PROJECT = "maven.ant.project";

    /** MavenSession POM context tag **/
    public static final String MAVEN_POM = "pom";

    /** MavenSession goals context tag **/
    public static final String MAVEN_GOALS = "maven.goals";

    /** MavenSession project verifier context tag **/
    public static final String MAVEN_PROJECT_VERIFIER = "maven.project.verifier";

    /** Werkz project context tag **/
    public static final String WERKZ_PROJECT = "org.apache.commons.jelly.werkz.Project";

    /** Reactor projects context tag **/
    public static final String REACTOR_PROJECT = "maven.reactorProjects";

    /** Plugin Manager tag. */
    public static final String PLUGIN_MANAGER = "maven.plugin.manager";

    /** Jelly XMLOutput tag. */
    public static final String XML_OUTPUT = "maven.xmlOutput";

    /** MavenSession debug flag tag. */
    public static final String DEBUG_ON = "maven.debugOn";

    /** MavenSession debug flag tag. */
    public static final String EMACS_MODE_ON = "maven.emacsModeOn";

    /**  Descriptor directory tag. (project.xml) */
    public static final String DESCRIPTOR_DIRECTORY = "maven.descriptorDirectory";

    /**  Project build file tag. (maven.xml) */
    public static final String BUILD_FILE = "maven.projectBuildFile";

    /**  Project descriptor file tag. (project.xml) */
    public static final String DESCRIPTOR_FILE = "maven.descriptorFile";

    /**  Dependency classpath tag. */
    public static final String DEPENDENCY_CLASSPATH = "maven.dependency.classpath";

    /**  Dependency classpath tag. */
    public static final String SESSION = "maven.session";

    /** Reactor/Maven subproject Build failure  tag. */
    public static final String BUILD_FAILURE = "maven.build.failure";

    /** Reactor/Maven subproject Build failure project list tag. */
    public static final String FAILED_PROJECTS = "failedProjects";

    /** Maven compile sourceroots. */
    public static final String COMPILE_SOURCEROOTS = "compile.sourceroots";

    /** Maven test compile sourceroots. */
    public static final String TEST_COMPILE_SOURCEROOTS = "test.compile.sourceroots";
}
