package org.apache.maven.jelly.tags;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.TagSupport;
import org.apache.maven.jelly.MavenJellyContext;

/**
 * A class for Maven Jelly tags
 */
public abstract class BaseTagSupport
    extends TagSupport
{
    /**
     * Create an instance
     */
    public BaseTagSupport()
    {
        super();
    }

    /**
     * @return the maven context (used to retrieve variables)
     */
    public MavenJellyContext getMavenContext()
    {
        return (MavenJellyContext) getContext();
    }

    /**
     * Check a given 'attribute' has a value and throw the corresponding
     * exception if it doesn't
     *
     * @param attribute the attribute to check
     * @param message the message to pass in with the exception
     * @throws MissingAttributeException when the attribute is null
     */
    protected void checkAttribute( Object attribute, String message )
        throws MissingAttributeException
    {
        if ( attribute == null )
        {
            throw new MissingAttributeException( message );
        }
    }

}
