package org.apache.maven.jelly.tags.jeez;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.impl.DynamicTagLibrary;
import org.apache.commons.jelly.tags.define.TagTag;

/**
 * This tag defines a dynamic tag in Jelly script. When the tag is invoked
 * any attributes will be passed in as variables and the definition of the
 * tag can use &lt;define:invokeBody&gt to invoke its body.
 * <p>
 * This tag is similar to the &lt;define:tag&gt; tag in the define
 * tag library.
 *
 * @author <a href="mailto:jstrachan@apache.org">James Strachan</a>
 * @version $Revision: 423634 $
 */
public class TagDefTag
    extends TagTag
{

    private DynamicTagLibrary tagLibrary;

    public TagDefTag( DynamicTagLibrary tagLibrary )
    {
        this.tagLibrary = tagLibrary;
    }

    /**
     * @return the current JeezTagLibrary instance
     */
    protected DynamicTagLibrary getTagLibrary()
        throws JellyTagException
    {
        return tagLibrary;
    }
}
