package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.File;
import java.util.Iterator;
import java.util.List;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.maven.jelly.tags.BaseTagSupport;
import org.apache.maven.project.Resource;
import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.PatternSet;

/**
 * A tag to copy resources to a given directory
 *
 * @version $Revision: 424660 $
 */
public class CopyResources
    extends BaseTagSupport
{
    /** log for debug output */
    private static final Log log = LogFactory.getLog( CopyResources.class );

    /** the resources to copy */
    private List resources;

    /** the directory to copy to */
    private String todir;

    /**
     * @see org.apache.commons.jelly.Tag#doTag(org.apache.commons.jelly.XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        if ( resources == null || todir == null )
        {
            log.warn( "resources or todir was null" );
            return;
        }
        //      <j:forEach var="resource" items="${resources}">
        //        <j:set var="resourceDirectoryPresent" value="false"/>
        //
        //        <util:available file="${resource.directory}">
        //          <j:set var="resourceDirectoryPresent" value="true"/>
        //        </util:available>
        //
        //        <j:if test="${resourceDirectoryPresent == 'true'}">
        //          <j:choose>
        //            <j:when test="${resource.targetPath ==''}">
        //              <j:set var="targetDirectory" value="${todir}"/>
        //            </j:when>
        //            <j:otherwise>
        //              <j:set var="targetDirectory" value="${todir}/${resource.targetPath}"/>
        //            </j:otherwise>
        //          </j:choose>
        //          <copy todir="${targetDirectory}" filtering="${resource.filtering}"
        //              overwrite="${resource.filtering}">
        //            <fileset dir="${resource.directory}">
        //              <j:if test="${resources.includes.isEmpty()}">
        //                <include name="**/**"/>
        //              </j:if>
        //              <j:forEach var="include" items="${resource.includes}">
        //                <include name="${include}"/>
        //              </j:forEach>
        //              <j:forEach var="exclude" items="${resource.excludes}">
        //                <exclude name="${exclude}"/>
        //              </j:forEach>
        //            </fileset>
        //          </copy>
        //        </j:if>
        //      </j:forEach>

        for ( Iterator iter = resources.iterator(); iter.hasNext(); )
        {
            Resource resource = (Resource) iter.next();
            String directoryName = resource.getDirectory();
            if ( directoryName == null )
            {
                continue;
            }
            File directory = new File( directoryName );
            if ( directory.exists() && directory.isDirectory() && directory.canRead() )
            {
                StringBuffer targetDirectoryBuffer = new StringBuffer( todir );
                String targetPath = resource.getTargetPath();
                if ( targetPath != null && !"".equals( targetPath.trim() ) )
                {
                    targetDirectoryBuffer.append( '/' ).append( targetPath );
                }
                File targetDirectory = new File( targetDirectoryBuffer.toString() );
                // copy to targetDirectory....
                org.apache.tools.ant.taskdefs.Copy copyTask = new org.apache.tools.ant.taskdefs.Copy();
                copyTask.setProject( getMavenContext().getAntProject() );
                copyTask.setTodir( targetDirectory );
                copyTask.setPreserveLastModified( true );
                copyTask.setFiltering( resource.isFiltering() );
                copyTask.setOverwrite( resource.isFiltering() );
                FileSet fileSet = new FileSet();
                fileSet.setDir( directory );
                if ( resource.getIncludes().isEmpty() )
                {
                    PatternSet.NameEntry entry = fileSet.createInclude();
                    entry.setName( "**/**" );
                }
                // add includes
                for ( Iterator incIter = resource.getIncludes().iterator(); incIter.hasNext(); )
                {
                    String include = (String) incIter.next();
                    PatternSet.NameEntry entry = fileSet.createInclude();
                    entry.setName( include );
                }
                // add excludes
                for ( Iterator incIter = resource.getExcludes().iterator(); incIter.hasNext(); )
                {
                    String exclude = (String) incIter.next();
                    PatternSet.NameEntry entry = fileSet.createExclude();
                    entry.setName( exclude );
                }
                copyTask.addFileset( fileSet );
                copyTask.execute();
            }
            else
            {
                log.debug( "todir is either not a directory, not writable or not there" );
            }
        }

    }

    /**
     * @param list the resources to copy
     */
    public void setResources( List list )
    {
        resources = list;
    }

    /**
     * @param string the directory to copy them to
     */
    public void setTodir( String string )
    {
        todir = string;
    }

}
