package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.Iterator;
import java.util.List;

import org.apache.maven.project.Project;

/**
 * @author <a href="mailto:bwalding@apache.org">Ben Walding</a>
 * @version $Id: DependencyResolver.java 423634 2006-07-19 22:13:40Z aheritier $
 */
public class DependencyResolver
    implements DependencyResolverInterface
{

    private final DependencyResolverInterface impl;

    /**
     * Creates the dependency resolver. The implementation is chosen by the
     * System property "maven.core.dependencyresolver".  By default it is
     * the WerkzDependencyResolver. Ultimately I see this proxy being removed.
     *
     * @see java.lang.Object#Object()
     */
    public DependencyResolver()
    {
        String prop = "maven.core.dependencyresolver";
        String type = System.getProperty( prop );
        try
        {

            if ( type == null )
            {
                impl = new WerkzDependencyResolver();
            }
            else
            {
                impl = (DependencyResolverInterface) Class.forName( type ).newInstance();
            }
        }
        catch ( Exception e )
        {
            throw new RuntimeException( "Unable to create " + type );
        }
    }

    /**
     * Creates the dependency resolver with a specific implementation
     *
     * @param impl
     */
    public DependencyResolver( DependencyResolverInterface impl )
    {
        this.impl = impl;
    }

    /**
     * @see org.apache.maven.jelly.tags.maven.DependencyResolverInterface#clear()
     */
    public void clear()
    {
        impl.clear();
    }

    /**
     * @see org.apache.maven.jelly.tags.maven.DependencyResolverInterface#setProjects(java.util.List)
     */
    public void setProjects( List projects )
    {
        impl.setProjects( projects );
    }

    /**
     * @see org.apache.maven.jelly.tags.maven.DependencyResolverInterface#getSortedDependencies(org.apache.maven.project.Project)
     */
    public List getSortedDependencies( Project project )
        throws DependencyResolverException
    {
        return impl.getSortedDependencies( project );
    }

    /**
     * @see org.apache.maven.jelly.tags.maven.DependencyResolverInterface#getSortedDependencies(org.apache.maven.project.Project, boolean)
     */
    public List getSortedDependencies( Project project, boolean sourceBuild )
        throws DependencyResolverException
    {
        return impl.getSortedDependencies( project, sourceBuild );
    }

    /**
     * @see org.apache.maven.jelly.tags.maven.DependencyResolverInterface#getSortedDependencies(boolean)
     */
    public List getSortedDependencies( boolean sourceBuild )
        throws DependencyResolverException
    {
        return impl.getSortedDependencies( sourceBuild );
    }

    public static Project getProject( List projects, String id )
    {
        Iterator iter = projects.iterator();
        while ( iter.hasNext() )
        {
            Project project = (Project) iter.next();
            if ( project.getId().equals( id ) )
            {
                return project;
            }
        }
        return null;

    }

}
