package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Copyright 2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.maven.jelly.MavenJellyContext;
import org.apache.maven.jelly.tags.BaseTagSupport;
import org.apache.maven.plugin.UnknownPluginException;
import org.apache.maven.project.Project;

/**
 * A tag to set plugin values
 */
public class SetTag
    extends BaseTagSupport
{
    /** log for debug output */
    private static final Log log = LogFactory.getLog( SetTag.class );

    /** the value to set */
    private Object value;

    /** the plugin in which the variable will be set */
    private String plugin;

    /** the name of the plugin property to retrieve */
    private String property;

    /**
     * @see org.apache.commons.jelly.Tag#doTag(org.apache.commons.jelly.XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws JellyTagException
    {
        checkAttribute( value, "value" );
        checkAttribute( plugin, "plugin" );
        checkAttribute( property, "property" );
        Project project = getMavenContext().getProject();
        try
        {
            MavenJellyContext context = project.getPluginContext( plugin );
            if ( context != null )
            {
                context.setVariable( property, value );
            }
            else
            {
                log.error( "context for plugin '" + plugin + "' in project '" + project + "' is null" );
            }
        }
        catch ( UnknownPluginException e )
        {
            log.error( "Plugin '" + plugin + "' in project '" + project + "' is not available" );
        }
        catch ( Exception e )
        {
            throw new JellyTagException( "Error loading plugin", e );
        }
    }

    /**
     * @return the plugin to retrieve the property from.
     */
    public String getPlugin()
    {
        return plugin;
    }

    /**
     * @return the name of the property being retrieved
     */
    public String getProperty()
    {
        return property;
    }

    /**
     * @return the value to set
     */
    public Object getValue()
    {
        return value;
    }

    /**
     * @param pluginId the id of the plugin in which the property will be set
     */
    public void setPlugin( String pluginId )
    {
        plugin = pluginId;
    }

    /**
     * @param propertyName the name of the property being set
     */
    public void setProperty( String propertyName )
    {
        property = propertyName;
    }

    /**
     * @param value the value to set
     */
    public void setValue( Object value )
    {
        this.value = value;
    }

}
