package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.jelly.tags.BaseTagSupport;
import org.apache.maven.project.Project;

/** Create snapshot signature for non-release JARs and distributions.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: SnapshotSignature.java 423634 2006-07-19 22:13:40Z aheritier $
 */
public class SnapshotSignature
    extends BaseTagSupport
{
    /** Maven project */
    private Project project;

    /**
     * Set the maven project object.
     *
     * @param project MavenSession project.
     */
    public void setProject( Project project )
    {
        this.project = project;
    }

    /**
     * Get the maven project object.
     *
     * @return MavenSession project.
     */
    public Project getProject()
    {
        return project;
    }

    /**
     * Process the tag. Create a variable in the current context of the format
     * <code>${pom.artifactId}-yyyyMMdd.HHmmss</code>
     *
     * @param output used to send XML output to Jelly
     * @throws MissingAttributeException if the project property is not set
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException
    {
        checkAttribute( project, "project" );

        Date now = new Date();
        SimpleDateFormat formatter = new SimpleDateFormat( "yyyyMMdd.HHmmss" );
        formatter.setTimeZone( TimeZone.getTimeZone( "GMT" ) );
        String snapshotVersion = formatter.format( now );
        String snapshotSignature = getProject().getArtifactId() + "-" + snapshotVersion;

        context.setVariable( "snapshotSignature", snapshotSignature );

        // We want to straight version so that we can deploy a marker
        // that will allow projects to flip between the 'SNAPSHOT'
        // identifier and a real snapshot version identifier.
        context.setVariable( "snapshotVersion", snapshotVersion );
    }
}
