package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.io.IOException;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.jelly.tags.BaseTagSupport;
import org.apache.maven.plugin.PluginManager;

/**
 * A Maven Jelly tag that will uninstall a given plugin JAR using the plugin manager.
 *
 * @author <a href="mailto:brett@apache.org">Brett Porter</a>
 * @version $Id: UninstallPluginTag.java 423634 2006-07-19 22:13:40Z aheritier $
 */
public class UninstallPluginTag
    extends BaseTagSupport
{
    private String artifactId;

    public void setArtifactId( String artifactId )
    {
        this.artifactId = artifactId;
    }

    /* (non-Javadoc)
     * @see org.apache.commons.jelly.Tag#doTag(org.apache.commons.jelly.XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        checkAttribute( artifactId, "artifactId" );

        PluginManager manager = getMavenContext().getMavenSession().getPluginManager();
        try
        {
            manager.uninstallPlugin( artifactId );
        }
        catch ( IOException e )
        {
            throw new JellyTagException( "error uninstalling plugin", e );
        }
    }
}
