package org.apache.maven.jelly.tags.maven;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.jelly.tags.BaseTagSupport;

/**
 * A tag to check if a user name is set.
 */
public class UserCheck
    extends BaseTagSupport
{
    /** the value that means no value has been set */
    private static final String NO_VALUE = "USERNAME_NOT_SET";

    /** Error message */
    private static final String ERROR = "+------------------------------------------------------------------\n"
        + "| ERROR!\n" + "| \n" + "| You must specify a maven username in order to deploy the site!\n"
        + "| You can either set this property in your ~/build.properties\n" + "| or specify one on the command line:\n"
        + "|\n" + "| maven -Dmaven.username=${user.name} [goal]"
        + "+------------------------------------------------------------------";

    /** the user to check has a value */
    private String user;

    /**
     * @see org.apache.commons.jelly.Tag#doTag(XMLOutput)
     */
    public void doTag( XMLOutput output )
        throws MissingAttributeException, JellyTagException
    {
        checkAttribute( user, "user" );

        user = user.trim();
        if ( "".equals( user ) || UserCheck.NO_VALUE.equals( user ) )
        {
            throw new JellyTagException( UserCheck.ERROR );
        }
    }

    /**
     * @param aString the value for the user property
     */
    public void setUser( String aString )
    {
        user = aString;
    }

}
