package org.apache.maven.plugin;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.maven.MavenException;

/** Indicates an attempt to access an unknown plugin.
 *
 * @author <a href="mailto:brett@apache.org">Brett Porter</a>
 * @version $Id: UnknownPluginException.java 423634 2006-07-19 22:13:40Z aheritier $
 */
public class UnknownPluginException
    extends MavenException
{
    /** Name of unknown plugin. */
    private String id;

    /** Construct with an unknown plugin name.
     *
     *  @param id the plugin ID
     */
    public UnknownPluginException( String id )
    {
        super( "Unknown plugin \"" + id + "\"" );
        this.id = id;
    }

    /** Retrieve the unknown plugin name.
     *
     *  @return The name of the unknown plugin.
     */
    public String getPluginId()
    {
        return this.id;
    }
}
