package org.apache.maven.repository;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.maven.project.Dependency;

/**
 * Simple factory for creating Artifact implementations based on a dependency
 * type.
 *
 * @author <a href="mailto:jason@zenplex.com">Jason van Zyl</a>
 * @version $Id: DefaultArtifactFactory.java 424460 2006-07-21 21:37:20Z aheritier $
 *
 * @todo The factor needs to take a properties file describing the acceptable
 *       types of artifacts. We can have a default set and also allow users
 *       to customize the list for their own purposes.
 */
public class DefaultArtifactFactory
{
    /**
     * Return an appropriate Artifact implementation based on the dependency
     * type.
     *
     * @param dependency The base dependency.
     * @todo not the intended usage of test type
     * @return The appropriate artifact based on the dependency type.
     */
    public static Artifact createArtifact( Dependency dependency )
    {
        //!! I certainly have to revisit this. As sometimes we get
        // any of the following conditions satisfied.
        if ( dependency.getType() == null || dependency.getType().trim().length() == 0
            || "jar".equals( dependency.getType() ) || "test".equals( dependency.getType() ) )
        {
            dependency.setType( "jar" );
            return new GenericArtifact( dependency );
        }
        else
        {
            return new GenericArtifact( dependency );
        }
    }
}
