package org.apache.maven.util;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.tools.ant.util.GlobPatternMapper;

/**
 * Implementation of FileNameMapper that does simple case insensitive
 * wildcard pattern replacements.
 *
 * <p>This does the same name translations as
 * <code>org.apache.tools.ant.util.GlobPatternMapper</code> does,
 * but ignores case when comparing parts of name with patterns.</p>
 *
 * @author <a href="mailto:barancev@ispras.ru">Alexei Baranstev</a>
 */
public class CaseInsensitiveGlobPatternMapper
    extends GlobPatternMapper
{

    /**
     * Returns null if the source file name doesn't match the
     * &quot;from&quot; pattern, an one-element array containing the
     * translated file otherwise.
     */
    public String[] mapFileName( String sourceFileName )
    {
        if ( fromPrefix == null || !sourceFileName.toLowerCase().startsWith( fromPrefix.toLowerCase() )
            || !sourceFileName.toLowerCase().endsWith( fromPostfix.toLowerCase() ) )
        {
            return null;
        }
        return new String[] { toPrefix + extractVariablePart( sourceFileName ) + toPostfix };
    }

}
