package org.apache.maven.util;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.maven.wagon.events.TransferEvent;
import org.apache.maven.wagon.events.TransferListener;

/**
 * Console download progress meter.
 *
 * @author <a href="mailto:brett@apache.org">Brett Porter</a>
 * @version $Id: ConsoleDownloadMeter.java 423634 2006-07-19 22:13:40Z aheritier $
 */
public class ConsoleDownloadMeter
    implements TransferListener
{
    /** log for debug output */
    private static final Log log = LogFactory.getLog( BootstrapDownloadMeter.class );

    private long complete;

    public void transferInitiated( TransferEvent transferEvent )
    {
        // this space left intentionally blank
    }

    public void transferStarted( TransferEvent transferEvent )
    {
        complete = 0;
    }

    public void transferProgress( TransferEvent transferEvent, byte[] buffer, int length )
    {
        long total = transferEvent.getResource().getContentLength();
        complete += length;
        System.out.print( ( complete / 1024 ) + "/" + ( total == 0 ? "?" : ( total / 1024 ) + "K" ) + "\r" );
    }

    public void transferCompleted( TransferEvent transferEvent )
    {
        long total = transferEvent.getResource().getContentLength();
        log.info( ( total / 1024 ) + "K downloaded" );
    }

    public void transferError( TransferEvent transferEvent )
    {
        log.error( transferEvent.getException().getMessage() );
    }

    public void debug( String message )
    {
        log.debug( message );
    }
}
