package org.apache.maven.util;

/* ====================================================================
 *   Copyright 2001-2004 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.text.DecimalFormat;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Formatting tool for use with the DVSL toolbox.  This class contains
 * static methods to assist in formatting needs that can't be done or
 * shouldn't be done in a DVSL stylesheet.
 *
 * @author <a href="mailto:pete-apache-dev@kazmier.com">Pete Kazmier</a>
 * @version $Id: DVSLFormatter.java 423634 2006-07-19 22:13:40Z aheritier $
 * @todo move to org.apache.maven.util or make a jelly tag
 */
public class DVSLFormatter
{
    /**
     * Instance of a formatter.
     */
    private static DecimalFormat formatter = new DecimalFormat();

    /**
     * Log for debug output
     */
    private static Log log = LogFactory.getLog( DVSLFormatter.class );

    /**
     * Formats a string as a number using the specified pattern.
     * Patterns are specified using the same format as <code>
     * java.text.DecimalFormat</code>.
     * <p/>
     * This method is thread-hostile.
     *
     * @see java.text.DecimalFormat
     * @param value The number to format.
     * @param pattern The pattern used to format.
     * @return A string formatted using the specified pattern.
     * @throws IllegalArgumentException If an invalid pattern is
     * specified.
     */
    public static final String formatNumber( final String value, final String pattern )
    {
        log.debug( "value = '" + value + "', pattern = '" + pattern + "'" );
        if ( pattern == null || value == null )
        {
            return "<error formatting: '" + value + "' with '" + pattern + "'>";
        }

        String ret = null;

        try
        {
            formatter = new DecimalFormat( pattern );
            Number valueAsNumber;
            try
            {
                valueAsNumber = Double.valueOf( value.trim() );
            }
            catch ( NumberFormatException nfe )
            {
                valueAsNumber = new Double( "0.00" );
            }

            if ( pattern.indexOf( "." ) != -1 || pattern.indexOf( "%" ) != -1 )
            {
                // parse as a decimal
                ret = formatter.format( valueAsNumber.doubleValue() );
            }
            else
            {
                // parse as an integer
                formatter.setParseIntegerOnly( true );
                ret = formatter.format( valueAsNumber.longValue() );
            }
            log.debug( "ret='" + ret + "'" );

        }
        catch ( Exception e )
        {
            log.error( "<error formatting: '" + value + "' with '" + pattern + "'>", e );
            return "<error formatting: '" + value + "' with '" + pattern + "'>";
        }

        return ret;
    }
}
