package org.apache.maven.werkz.jelly;

/* ====================================================================
 *   Copyright 2001-2005 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

/*
 $Id: GoalTag.java 423634 2006-07-19 22:13:40Z aheritier $

 Copyright 2002 (C) The Werken Company. All Rights Reserved.

 Redistribution and use of this software and associated documentation
 ("Software"), with or without modification, are permitted provided
 that the following conditions are met:

 1. Redistributions of source code must retain copyright
 statements and notices.  Redistributions must also contain a
 copy of this document.

 2. Redistributions in binary form must reproduce the
 above copyright notice, this list of conditions and the
 following disclaimer in the documentation and/or other
 materials provided with the distribution.

 3. The name "werkz" must not be used to endorse or promote
 products derived from this Software without prior written
 permission of The Werken Company.  For written permission,
 please contact bob@werken.com.

 4. Products derived from this Software may not be called "werkz"
 nor may "werkz" appear in their names without prior written
 permission of The Werken Company. "werkz" is a registered
 trademark of The Werken Company.

 5. Due credit should be given to "the werkz project"
 ( http://werkz.werken.com/ ).

 THIS SOFTWARE IS PROVIDED BY THE WERKEN COMPANY AND CONTRIBUTORS
 ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 THE WERKEN COMPANY OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 OF THE POSSIBILITY OF SUCH DAMAGE.

 */

import java.util.StringTokenizer;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.maven.werkz.Action;
import org.apache.maven.werkz.CyclicGoalChainException;
import org.apache.maven.werkz.DefaultAction;
import org.apache.maven.werkz.Goal;
import org.apache.maven.werkz.Session;

/**
 * Implements a &lt;target&gt; tag which is similar to the Ant equivalent tag
 * but is based on the Werkz goal engine.
 *
 * @author <a href="mailto:jstrachan@apache.org">James Strachan</a>
 * @version $Revision: 1.3 $
 */
public class GoalTag
    extends WerkzTagSupport
{

    /** The Log to which logging calls will be made. */
    private Log log = LogFactory.getLog( GoalTag.class );

    /** the name of the target */
    private String name;

    private String prereqs;

    private String description;

    public GoalTag()
    {
    }

    // Tag interface
    //-------------------------------------------------------------------------

    /**
     * Evaluate the body to register all the various goals and pre/post conditions
     * then run all the current targets
     */
    public void doTag( final XMLOutput output )
        throws JellyTagException
    {

        log.debug( "doTag(..):" + name );

        Goal goal = getProject().getGoal( getName(), true );

        goal.setDescription( this.description );
        try
        {
            addPrereqs( goal );
        }
        catch ( CyclicGoalChainException e )
        {
            throw new JellyTagException( e );
        }

        Action action;

        action = getAction();

        if ( action == null )
        {
            action = new DefaultAction()
            {
                public void performAction( Session session )
                    throws Exception
                {
                    performAction();
                }

                public void performAction()
                    throws Exception
                {
                    log.debug( "Running action of target: " + getName() );
                    invokeBody( output );
                }
            };
        }

        goal.setAction( action );
    }

    // Properties
    //-------------------------------------------------------------------------
    /**
     * @return the name of the target
     */
    public String getName()
    {
        return name;
    }

    /**
     * Sets the name of the target
     */
    public void setName( String name )
    {
        log.debug( "setName(" + name + ")" );
        this.name = name;
    }

    public void setPrereqs( String prereqs )
    {
        this.prereqs = prereqs;
    }

    public String getPrereqs()
    {
        return this.prereqs;
    }

    public void setDescription( String description )
    {
        this.description = description;
    }

    protected void addPrereqs( Goal goal )
        throws CyclicGoalChainException
    {
        String prereqs = getPrereqs();

        if ( prereqs == null )
        {
            return;
        }

        StringTokenizer tokens = new StringTokenizer( getPrereqs(), "," );

        String eachToken = null;
        Goal eachPrereq = null;

        while ( tokens.hasMoreTokens() )
        {
            eachToken = tokens.nextToken().trim();

            eachPrereq = getProject().getGoal( eachToken, true );

            goal.addPrecursor( eachPrereq );
        }
    }

    /**
     * Subclasses can override this template method to provide a
     * custom <code>Action</code> implementation. This scenerio will
     * most likely come into play when you have also created a custom
     * <code>Session</code> implementation that can be used to provide
     * parameters during the attainment of a <code>Goal</code>.
     */
    protected Action getAction()
    {
        return null;
    }
}
