package org.apache.maven.werkz.jelly;

/* ====================================================================
 *   Copyright 2001-2005 The Apache Software Foundation.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

/*
 $Id: UseGoalsTag.java 423634 2006-07-19 22:13:40Z aheritier $

 Copyright 2002 (C) The Werken Company. All Rights Reserved.

 Redistribution and use of this software and associated documentation
 ("Software"), with or without modification, are permitted provided
 that the following conditions are met:

 1. Redistributions of source code must retain copyright
 statements and notices.  Redistributions must also contain a
 copy of this document.

 2. Redistributions in binary form must reproduce the
 above copyright notice, this list of conditions and the
 following disclaimer in the documentation and/or other
 materials provided with the distribution.

 3. The name "werkz" must not be used to endorse or promote
 products derived from this Software without prior written
 permission of The Werken Company.  For written permission,
 please contact bob@werken.com.

 4. Products derived from this Software may not be called "werkz"
 nor may "werkz" appear in their names without prior written
 permission of The Werken Company. "werkz" is a registered
 trademark of The Werken Company.

 5. Due credit should be given to "the werkz project"
 ( http://werkz.werken.com/ ).

 THIS SOFTWARE IS PROVIDED BY THE WERKEN COMPANY AND CONTRIBUTORS
 ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 THE WERKEN COMPANY OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 OF THE POSSIBILITY OF SUCH DAMAGE.

 */

import java.util.Iterator;
import java.util.Map;
import java.util.TreeMap;

import org.apache.commons.jelly.JellyTagException;
import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.maven.werkz.Goal;

/**
 * This tag outputs a sorted Map of Maps all of the goals, indexed by their prefix and their
 * goal name. This is output to a variable. This map of maps makes it easy to navigate the
 * available Goals.
 * <p>
 * So if the goals is output to a variable called 'g' then you can access a specific goal via
 * a Jexl expression ${g.java.compile} or to find all the 'java' goals you can use ${g.java} which
 * returns a sorted Map.
 *
 * @author <a href="mailto:jstrachan@apache.org">James Strachan</a>
 * @version $Revision: 1.2 $
 */
public class UseGoalsTag
    extends WerkzTagSupport
{
    /** the name of the variable to export */
    private String var;

    public UseGoalsTag()
    {
    }

    // Tag interface
    //-------------------------------------------------------------------------

    /**
     * Evaluate the body to register all the various goals and pre/post conditions
     * then run all the current targets
     */
    public void doTag( final XMLOutput output )
        throws JellyTagException
    {
        if ( var == null )
        {
            throw new MissingAttributeException( "var" );
        }

        Map answer = createMap();

        Iterator iter = getProject().getGoals().iterator();
        while ( iter.hasNext() )
        {
            Goal goal = (Goal) iter.next();
            String name = goal.getName();
            String prefix = name;
            int idx = name.indexOf( ":" );
            if ( idx >= 0 )
            {
                prefix = name.substring( 0, idx );
                name = name.substring( idx + 1 );
            }
            else
            {
                name = "[default]";
            }

            Map map = (Map) answer.get( prefix );
            if ( map == null )
            {
                map = createMap();
                answer.put( prefix, map );
            }
            map.put( name, goal );
        }

        context.setVariable( var, answer );
    }

    // Properties
    //-------------------------------------------------------------------------
    /**
     * Sets the variable for which the Map of Map of goals will be exported
     */
    public void setVar( String var )
    {
        this.var = var;
    }

    /**
     * Factory method to create a new sorted map
     */
    protected Map createMap()
    {
        return new TreeMap();
    }
}
